==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridColumnsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnsChangedEventArgsDescription } from "./GridColumnsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridColumnsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnsChangedEventArgsDescriptionMetadata, _super);
    function GridColumnsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridColumnsChangedEventArgsDescriptionMetadata.a == null) {
            GridColumnsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnsChangedEventArgsDescriptionMetadata.c(GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridColumnsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridColumnsChangedEventArgsDescriptionMetadata.a);
    };
    GridColumnsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Columns", "Collection:DataGridColumn:GridColumnCollection:DataGridColumn");
    };
    GridColumnsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridColumnsChangedEventArgsDescriptionMetadata.b(a);
        a.ac("GridColumnsChangedEventArgs", function () { return new GridColumnsChangedEventArgsDescription(); });
        a.ab("GridColumnsChangedEventArgs", GridColumnsChangedEventArgsDescriptionMetadata.a);
    };
    GridColumnsChangedEventArgsDescriptionMetadata.$t = markType(GridColumnsChangedEventArgsDescriptionMetadata, 'GridColumnsChangedEventArgsDescriptionMetadata');
    GridColumnsChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridColumnsChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridColumnsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnsChangedEventArgsDescription } from "./GridColumnsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridColumnsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnsChangedEventArgsDescriptionMetadata, _super);
    function GridColumnsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridColumnsChangedEventArgsDescriptionMetadata.a == null) {
            GridColumnsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnsChangedEventArgsDescriptionMetadata.c(GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridColumnsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridColumnsChangedEventArgsDescriptionMetadata.a);
    };
    GridColumnsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Columns", "Collection:DataGridColumn:GridColumnCollection:DataGridColumn");
    };
    GridColumnsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridColumnsChangedEventArgsDescriptionMetadata.b(a);
        a.ae("GridColumnsChangedEventArgs", function () { return new GridColumnsChangedEventArgsDescription(); });
        a.ad("GridColumnsChangedEventArgs", GridColumnsChangedEventArgsDescriptionMetadata.a);
    };
    GridColumnsChangedEventArgsDescriptionMetadata.$t = markType(GridColumnsChangedEventArgsDescriptionMetadata, 'GridColumnsChangedEventArgsDescriptionMetadata');
    GridColumnsChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridColumnsChangedEventArgsDescriptionMetadata };
